Indexing Routines
=================

.. https://docs.scipy.org/doc/numpy/reference/routines.indexing.html

.. autosummary::
   :toctree: generated/
   :nosignatures:

   cupy.c_
   cupy.r_
   cupy.nonzero
   cupy.where
   cupy.indices
   cupy.ix_
   cupy.ravel_multi_index
   cupy.unravel_index
   cupy.take
   cupy.take_along_axis
   cupy.choose
   cupy.compress
   cupy.diag
   cupy.diagonal
   cupy.extract
   cupy.select
   cupy.lib.stride_tricks.as_strided
   cupy.place
   cupy.put
   cupy.putmask
   cupy.fill_diagonal
   cupy.flatiter
